/*
 *   ORXONOX - the hottest 3D action shooter ever to exist
 *                    > www.orxonox.net <
 *
 *
 *   License notice:
 *
 *   This program is free software; you can redistribute it and/or
 *   modify it under the terms of the GNU General Public License
 *   as published by the Free Software Foundation; either version 2
 *   of the License, or (at your option) any later version.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with this program; if not, write to the Free Software
 *   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 *
 *   Author:
 *      Florian Zinggeler
 *   Co-authors:
 *      ...
 *
 */

/**
    @file Asteroids2DShip.h
    @brief Declaration of the Asteroids2DShip class.
*/

#ifndef _Asteroids2DShip_H__
#define _Asteroids2DShip_H__


#include "asteroids2D/Asteroids2DPrereqs.h"

#include "worldentities/pawns/SpaceShip.h"
#include "tools/Timer.h"

namespace orxonox
{
    class _Asteroids2DExport Asteroids2DShip : public SpaceShip
    {
        public:
            Asteroids2DShip(Context* context);

            virtual void tick(float dt) override;

            //no rotation in x and z direction!
            virtual void rotatePitch(const Vector2& value) override{}; // Rotate in pitch direction.
            virtual void rotateRoll(const Vector2& value) override{}; // Rotate in roll direction.
            virtual void boost(bool boost) override; //Override, so that the ship does not shake
            virtual void updateLevel();

            virtual inline bool collidesAgainst(WorldEntity* otherObject, const btCollisionShape* ownCollisionShape, btManifoldPoint& contactPoint) override;
            
            /*Functions that can be helpful while debugging.
                - Set a timer so that the function is called for instance every 3s to display the coordinates
                - Open console with "~`"-key in when you start the Asteroids2D - Minigame.
            */
            void showposition();
            void showorientation();


            void toggleImmune()
            {
                bImmune = !bImmune;
            }

        protected:
            virtual void death() override;

        private:
            Asteroids2D* getGame();

            float width, height;
            WeakPtr<Asteroids2D> game;
            bool bImmune;
            Timer timer;
            Timer isimmune;
    };
}

#endif /* _Asteroids2DShip_H__ */
